function h=dsbesselh(nu,K,Z)
%DSBESSELH Derivative of the spherical Bessel function of the third kind
%         (Hankel function).
%   H = DSBESSELH(NU,K,Z), for K = 1 or 2, computes the derivative of
%   Hankel function H1_nu(Z) or H2_nu(Z) for each element of the complex 
%   array Z.
%
%   If NU and Z are arrays of the same size, the result is also that size.
%   If either input is a scalar, it is expanded to the other input's size.
%

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)


hs1=sbesselh(nu-1,K,Z);
hs2=sbesselh(nu+1,K,Z);
h=(nu.*hs1-(nu+1).*hs2)./(2*nu+1);
end


