%ELLRES COMPUTES THE MODE INDEX AT RESONANCE
%   ELLRES computes, for a given wavelength, the values of the mode index
%   ell for which a resonance occurs

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

clear 
close all
expert_mode=0; % set to 1 for using the program in expert mode
%
% Data reading 
%
R=input('Micro-sphere radius [micro-m] = ');
N=input('Optical index of the micro-sphere = ');
TEM=input('TE or TM mode ? (TE/TM) : ','s');
if strcmp(TEM,'te')
    TEM='TE';
end
if strcmp(TEM,'TE')
    P=N;
else
    P=1/N;
end
lambda=input('Wavelength [nm] = ');
lambda=1E-3*lambda;  % units conversion in micro-m
k0=2*pi/lambda;
k=N*k0;
%
% Determine the interval of interest for ell 
%
if expert_mode==0
    deltap=lambda*P/(2*pi*N*sqrt(N^2-1));
    ell1=-0.5+2*pi*(R+deltap)/lambda;
    ell2=-0.5+2*N*pi*(R+deltap)/lambda; 
else
    Inofin=input('Interval of interest for the mode indices search : ');
    ell1=Inofin(1);
    ell2=Inofin(2);
end
%
% Plot the modal equation function which is discontinuous
%
hpas=(ell2-ell1)/10000;
x=ell1:hpas:ell2;
y=modeqel(x,P,k0,k,R,TEM);

if expert_mode==1 
    plotd(x,y);
    ylim([-1 1])
    hold on
    plot([ell1 ell2], [0 0], 'x-k','LineWidth',2); % emphasis the zero value
    if strcmp(TEM,'TE')
        title('Modale function for TE modes')
    else
        title('Modale function for TM modes')
    end
    xlabel('Polar mode index')
    grid
end
%
% Looking for all the zeros  
%
tol=1;
j=0;
options = optimset('TolFun',1E-9,'TolX',1E-9);
for i=1:length(x)-1
    % the test ensures that we have a sign change but not a discontinuity
    if (y(i+1)*y(i)<0)&&(abs(y(i+1)-y(i))<tol)
        j=j+1;
        ell(j)=fzero(@(x)modeqel(x,P,k0,k,R,TEM),[x(i),x(i+1)],options);
    end
end
if j==0
    disp('No solution found ... ')
    return
end
disp(' ')
disp('Polar mode indexes ell: ')
disp(' ')
formatSpec = '| %3d | %6.3f |';
ell=fliplr(ell);
for j=1:length(ell)
  tmp=sprintf(formatSpec,j,ell(j));
  disp(tmp);
end
