function [f,g] = fopte(x,ell,m)
%FOPTE : objective function use to compute the maximum of the square of the
% euclidean norm of the electric field for TE modes and gradient of the
% objective function 

% VARIABLES IN :
% x : current variable
% ell : resonance index
% m : resonance index
%
% VARIABLES OUT:
% f : objective function 
% g : gradient of the objective function 
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

% Calculate objective function
f =  - ((m^2+1)*slegend(ell,m,x).^2+...
    (ell-m+1)*(ell+m+1)*slegend(ell+1,m,x).^2-...
    2*sqrt((ell-m+1)*(ell+m+1))*slegend(ell,m,x).*...
    slegend(ell+1,m,x) ) ./ (1-x).^2;

if nargout > 1 % gradient required
    A1=-2*(-x*m^2*ell -2*x*m^2-x*ell-2*x+ell^2+2*ell-m^2+1)/(x^2-1)^2;
    A2=2*(-2*m^2+ell^2+2*ell-2*x)*sqrt((ell+1+m)*(ell-m+1))/(x^2-1)^2;
    A3=-2*(ell-m+1)*(x*ell-1)*(ell+1+m)/(x^2-1)^2;
    
    g = A1*slegend(ell,m,x).^2+A2*slegend(ell,m,x)*slegend(ell+1,m,x)+... 
        A3*slegend(ell+1,m,x)^2;
end