function[f,g]=foptm(x,k,ell,m)
%FOPTM : objective function use to compute the maximum of the square of the
% euclidean norm of the electric field for TM modes and gradient of the
% objective function 

% VARIABLES IN :
% x : current variable
% k : propagation constant in the dielectric cavity
% ell : resonance index
% m : resonance index
%
% VARIABLES OUT:
% f : objective function 
% g : gradient of the objective function 
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

x1=x(1);
x2=x(2);
B1=besselj(ell-1/2,k*x1);
B2=besselj(ell+1/2,k*x1);
S1=slegend(ell,m,x2);
S2=slegend(ell+1,m,x2);

C1=(1/2)*pi*(-m^2*k^2*x1^2-k^2*x1^2)*B1^2/(k^3*x1^3*(-1+x2^2))+...
(1/2)*pi*(2*ell*k*x1*m^2+2*ell*k*x1)*B2*B1/(k^3*x1^3*(-1+x2^2))+...
(1/2)*pi*(-ell^4+ell^4*x2^2-2*ell^3+2*ell^3*x2^2-2*ell^2+ell^2*x2^2-...
ell^2*m^2)*B2^2/(k^3*x1^3*(-1+x2^2));

C2=pi*sqrt((ell+1+m)*(ell-m+1))*B1^2/(k*x1*(-1+x2^2))-...
2*pi*B2*ell*sqrt((ell+1+m)*(ell-m+1))*B1/(k^2*x1^2*(-1+x2^2))+...
ell^2*B2^2*pi*sqrt((ell+1+m)*(ell-m+1))/(k^3*x1^3*(-1+x2^2));

C3=-(1/2)*pi*(ell-m+1)*(ell+1+m)*B1^2/(k*x1*(-1+x2^2))+...
pi*B2*ell*(ell-m+1)*(ell+1+m)*B1/(k^2*x1^2*(-1+x2^2))-...
(1/2)*ell^2*B2^2*pi*(ell-m+1)*(ell+1+m)/(k^3*x1^3*(-1+x2^2));


%Calculateobjectivef
f=-( C1*S1^2+C2*S1*S2+C3*S2^2 );

if nargout>1 %gradientrequired
    K1=pi*(k^2*x1^2*m^2+k^2*x1^2)*B1^2/(k^3*x1^4*(-1+x2^2))+...
        pi*(-2*ell^3*k*x1+2*ell^3*k*x1*x2^2-3*k*x1*m^2*ell-ell^4*k*x1+...
        k^3*x1^3+k^3*x1^3*m^2-2*ell^2*k*x1+ell^4*k*x1*x2^2-3*ell*k*x1-...
        k*x1*m^2*ell^2+ell^2*k*x1*x2^2)*B2*B1/(k^3*x1^4*(-1+x2^2))+...
        pi*(4*ell^2+6*ell^3+ell^5-ell*k^2*x1^2-4*ell^4*x2^2-5*ell^3*x2^2-...
        2*ell^2*x2^2-ell*m^2*k^2*x1^2+2*ell^2*m^2-ell^5*x2^2+ell^3*m^2+...
        4*ell^4)*B2^2/(k^3*x1^4*(-1+x2^2));
    
    K2=-(2*(ell-m+1))*pi*sqrt((ell+1+m)/(ell-m+1))*B1^2/(k*x1^2*(-1+x2^2))-...
        (2*(-(ell-m+1)*ell*pi*k*x1+(ell-m+1)*k*x1*pi*(-2*ell+k^2*x1^2-ell^2)))*...
        sqrt((ell+1+m)/(ell-m+1))*B2*B1/(k^3*x1^4*(-1+x2^2))+...
        (2*(ell-m+1))*ell*pi*(-2*ell+k^2*x1^2-ell^2)*...
        sqrt((ell+1+m)/(ell-m+1))*B2^2/(k^3*x1^4*(-1+x2^2));
    
    K3=(ell-m+1)*pi*(ell+1+m)*B1^2/(k*x1^2*(-1+x2^2))+(-(ell-m+1)*ell*pi*k*x1+...
        (ell-m+1)*k*x1*pi*(-2*ell+k^2*x1^2-ell^2))*...
        (ell+1+m)*B2*B1/(k^3*x1^4*(-1+x2^2))-(ell-m+1)*ell*pi*(-2*ell+...
        k^2*x1^2-ell^2)*(ell+1+m)*B2^2/(k^3*x1^4*(-1+x2^2));

    L1=-pi*(k^2*x1^2+ell^2*k^2*x1^2-2*m^2*x2*k^2*x1^2-x2*ell*k^2*x1^2-...
        m^2*k^2*x1^2-m^2*x2*ell*k^2*x1^2-2*x2*k^2*x1^2+2*ell*k^2*x1^2)*B1^2 ...
        /(k^3*x1^3*(-1+x2^2)^2)-pi*(4*x2*ell*k*x1-2*ell*k*x1+2*m^2*ell*k*x1+ ...
        2*x2*ell^2*k*x1-2*ell^3*k*x1+4*m^2*x2*ell*k*x1-4*ell^2*k*x1+ ...
        2*m^2*x2*ell^2*k*x1)*B2*B1/(k^3*x1^3*(-1+x2^2)^2)- ...
        pi*(ell^5*x2^3+3*ell^3*x2^3+ell^2*x2^3+3*ell^4*x2^3+2*ell^3+ell^2+...
        ell^4-ell^5*x2-ell^2*m^2-4*ell^3*x2-3*ell^2*x2-3*ell^4*x2-ell^3*m^2*x2-...
        2*m^2*x2*ell^2)*B2^2/(k^3*x1^3*(-1+x2^2)^2);
    
    L2=pi*(ell^3*k^2*x1^2-2*m^2*ell*k^2*x1^2+3*ell^2*k^2*x1^2+2*m^3*k^2*x1^2-...
        2*x2*ell*k^2*x1^2-2*x2*k^2*x1^2-2*m^2*k^2*x1^2-ell^2*m*k^2*x1^2-...
        2*ell*m*k^2*x1^2+2*x2*m*k^2*x1^2+2*ell*k^2*x1^2)/(k^3)/(x1^3)/((-1+x2^2)^2)*...
        sqrt(((ell+1+m)/(ell-m+1)))*B1^2+pi*(4*ell^2*m*k*x1-4*ell^2*k*x1-4*x2*ell*m*k*x1 ...
        -4*m^3*ell*k*x1+2*ell^3*m*k*x1+4*x2*ell*k*x1-6*ell^3*k*x1+4*x2*ell^2*k*x1-...
        2*ell^4*k*x1+4*m^2*ell^2*k*x1+4*m^2*ell*k*x1)/(k^3)/(x1^3)/((-1+x2^2)^2)*...
        sqrt(((ell+1+m)/(ell-m+1)))*B2*B1+pi*(-2*ell^3*m^2-ell^3-ell^2-2*ell^2*m^2-...
        2*ell^3*x2-2*ell^2*x2-ell^4*m*x2^2+ell^2*m+2*ell^2*m^3+3*ell^4*x2^2+...
        ell^2*x2^2+ell^5*x2^2+3*ell^3*x2^2-ell^2*m*x2^2+2*x2*ell^2*m-...
        2*ell^3*m*x2^2)/(k^3)/(x1^3)/((-1+x2^2)^2)*sqrt(((ell+1+m)/(ell-m+1)))*B2^2;
    
    L3=-(ell+1+m)*(ell^2*x2*k^2*x1^2-ell*m*x2*k^2*x1^2-ell*k^2*x1^2+...
        x2*ell*k^2*x1^2-k^2*x1^2+m*k^2*x1^2)*pi*B1^2/(k^3*x1^3*(-1+x2^2)^2)-...
        (ell+1+m)*(-2*x2*ell^2*k*x1-2*ell^3*x2*k*x1+2*ell^2*k*x1+2*x2*ell^2*m*k*x1-...
        2*m*ell*k*x1+2*ell*k*x1)*pi*B2*B1/(k^3*x1^3*(-1+x2^2)^2)-...
        (ell+1+m)*(ell^4*x2-ell^3*m*x2-ell^3+ell^2*m+ell^3*x2-ell^2)*pi*B2^2/(k^3*x1^3*(-1+x2^2)^2);
    
    g(1)=-( K1*S1^2+K2*S1*S2+K3*S2^2 );
    g(2)=-( L1*S1^2+L2*S1*S2+L3*S2^2 );
    
end
