function y=intgdl(ell,z,P,N)
% INTGDL Computes the integrand in the Delves-Lyness Method used to solve the
% modal equation in the complex plane

% VARIABLES IN :
% ell : polar mode index
% z : current variable
% P : N for TE modes and 1/N for TM modes
% N : optical index of the cavity
%
% VARIABLES OUT:
% y : value of the integrand
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

% computation of the modal function
qj= besselj(ell-0.5,N*z)./besselj(ell+0.5,N*z);
qh= besselh(ell-0.5,2,z)./besselh(ell+0.5,2,z);
f = P*qj - qh +(ell./z)*(1-P/N);
% computation of the derivative of the modal function
A=-qj.^2-1+2*(ell./(N*z)).*qj;
B=-qh.^2-1+2*(ell./z).*qh;
% A= -(1-qh).^2+2*(ell./z-1).*qh;
%B= N*P*(-(1-qj).^2+2*(ell./(N*z)-1).*qj);
C= (ell./z.^2)*(1-P/N);
df = P*N*A - B - C ; 
% computation of the integrand
y=df./f;
