function eq = modeqel(ell,P,k0,k,R,TEM)
%MODEQEL : modal equation for te or tm modes for a fixed wavelength and a
%          variable mode index ell

% VARIABLES IN :
% ell : resonance index
% P : N for TE modes and 1/N for TM modes
% k0 : propgation constant in vacuum
% k : propagation constant in the dielectric cavity
% R : micro-sphere radius
% TEM : selector for TE or TM modes
%
% VARIABLES OUT:
% eq : value of the modal function for the parameters provided
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)


x=k*R;
y=k0*R;

if strcmp(TEM,'TE') % TE mode
    eq=P*besselj(ell-0.5,x)./besselj(ell+0.5,x)-...
       bessely(ell-0.5,y)./bessely(ell+0.5,y);
else % TM mode
    eq=ell*(1-P^2)/(R*k0)+...
        P*besselj(ell-0.5,x)./besselj(ell+0.5,x)-...
        bessely(ell-0.5,y)./bessely(ell+0.5,y);
end

end

