function eq = modeqwv(lambda,ell,P,R,N,TEM)
%MODEQVW Modal equation for TE OR TM modes for a fixed mode index ell and 
%        a variable wavelength lambda

% VARIABLES IN :
% lambda : wavelength in mu-m
% ell : resonance index
% P : N for TE modes and 1/N for TM modes
% R : micro-sphere radius
% N : optical index of the cavity
% TEM : selector for TE or TM modes
%
% VARIABLES OUT:
% eq : value of the modal function for the parameters provided
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

k0=2*pi./lambda; % wave number in vaccum
k=N*k0;          % wave number in the micro-sphere
x=k*R;
y=k0*R;
if strcmp(TEM,'TE') % TE mode (RHS of the modal eq. is zero)
    eq=P*besselj(ell-0.5,x)./besselj(ell+0.5,x)-...
        bessely(ell-0.5,y)./bessely(ell+0.5,y);
else % TM mode
    eq=ell*(1-1/N^2)./(R*k0)+...
        P*besselj(ell-0.5,x)./besselj(ell+0.5,x)-...
        bessely(ell-0.5,y)./bessely(ell+0.5,y);
end

