%PLTMOD PLOT TE AND TM WG MODES IN A MICRO-SPHERE 
%   PLTMOD plot the whispering gallery modes in optical micro-sphere 

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

clear 
close all
expert_mode=0;
I=sqrt(-1);
cc=299792458E+6; % speed of light in vacuum in micro-m/s
R=input('Micro-sphere radius [micro-m] R = ');
N=input('Optical index of the micro-sphere = ');

tetm=input('TE or TM  mode : ','s');
if strcmp(tetm,'TE')||strcmp(tetm,'te')
    tetm='TE';
else
    tetm='TM';
end

lambda=input('Wavelength [nm] = ');
lambda=1E-3*lambda;  % unit conversion in micro-m
omega=2*pi*cc/lambda;
k0=2*pi/lambda;
k=N*k0;

ell=input('Mode number ell = ');
m=input('Mode number m = ');
disp(' Drawing options : ')
disp(' (A) 1D-plot in the radial direction');
disp(' (B) 2D-plot in an azimuthal plane phi=cste');
disp(' (C) 2D-plot in a polar plane theta=cste');
repp=input('Your choice (A/B/C) = ', 's');
if strcmp(repp,'a'), repp='A'; end

if strcmp(repp,'B')
    phi=input('Azimuthal angle [radian] : phi = ');
elseif  strcmp(repp,'C')
    theta=input('Polar angle [radian] : theta = ');
else
    phi=0;
    theta=pi/2;
end
% Switch depending on the figure to draw
switch repp
%----------------
    case 'A'
%----------------  
Rmin=input(' Minimum radial distance (\% value of R) = ');
Rmin=Rmin*R/100;
Rmax=input(' Maximal radial distance (\% value of R) = ');
Rmax=Rmax*R/100;
r=linspace(Rmin,Rmax,1000);
[E,B]=modefield(ell,m,r,theta,phi,tetm,lambda,R,N);
E=E./max(E);
B=B./max(B);
figure
subplot(2,1,1)
[vR,iR]=max(r>R); % we must take into account the discontinuity of E across the interface
if vR==1 && strcmp(tetm,'TM')  % E has a jump at the interface
    iR=iR-1;
    plot(r(1:iR)*1e6,E(1:iR),'-b')
    hold on
    plot(r(1+iR:length(r))*1e6,E(1+iR:length(r)),'-b')
    grid
else
    plot(r,E,'-b')
    grid
end
title('Norm of the electric field')
xlabel('Radial position in mu-m')
ylabel('Norm in arb. unit')
subplot(2,1,2)
plot(r,B,'-r')
grid
title('Norm of the magnetic induction')
xlabel('Radial position in mu-m')
ylabel('Norm in arb. unit')

%----------------
    case 'B'
%---------------- 
if expert_mode==1
    Rmin=input(' Minimum radial distance (\% value of R) = ');
    Rmin=Rmin*R/100;
    Rmax=input(' Maximal radial distance (\% value of R) = ');
    Rmax=Rmax*R/100;
    Tmin=input(' Minimum polar angle [radian] = ');
    Tmax=input(' Maximal polar angle [radian] = ');
else
    Rmin=0; 
    Rmax=input(' Maximal radial distance (\% value of R) = ');
    Rmax=Rmax*R/100;
    Tmin=0; Tmax=pi;
end
% generate meshgrid for the plots
pasR=(Rmax-Rmin)/200;
pasth=(Tmax-Tmin)/100;
[tht,rt] = meshgrid(Tmin:pasth:Tmax,Rmin:pasR:Rmax);
[X,Y] = pol2cart(tht,rt);

E=zeros(size(rt));
B=zeros(size(rt));

 for j=1:size(tht,2)
     [Ei,Bi]=modefield(ell,m,rt(:,1),tht(1,j),phi,tetm,lambda,R,N);
     E(:,j)=Ei;
     B(:,j)=Bi;
 end
E=E./max(max(E));
B=B./max(max(B));
%
% Plot the electric field
%
figure
colormap(jet)
contourf(X,Y,E)
h = findobj('Type','patch');
set(h,'LineStyle','none')
colorbar
axis equal
xlabel([' micro-m '],'FontSize',14);
ylabel([' micro-m '],'FontSize',14);
 title(['|E|  for ell=',num2str(ell),', m=',...
        num2str(m),', azimuth=',num2str(phi)],'FontSize',14);
figure
%
% Plot the magnetic field
%
colormap(jet)
contourf(X,Y,B)
h = findobj('Type','patch');
set(h,'LineStyle','none')
colorbar
axis equal
xlabel([' micro-m  '],'FontSize',14);
ylabel([' micro-m  '],'FontSize',14);
title(['|B| for ell=',num2str(ell),', m=',...
       num2str(m),', azimuth=',num2str(phi)],'FontSize',14);
%----------------
    case 'C'
%----------------
if expert_mode==1
    Rmin=input(' Minimum radial distance (\% value of R) = ');
    Rmin=Rmin*R/100;
    Rmax=input(' Maximal radial distance (\% value of R) = ');
    Rmax=Rmax*R/100;
    Pmin=input(' Minimum azimuthal angle = ');
    Pmax=input(' Maximal azimuthal angle = ');
else
    Rmin=0;
    Rmax=input(' Maximal radial distance (\% value of R) = ');
    Rmax=Rmax*R/100;
    Pmin=0; Pmax=2*pi;
end
% generate meshgrid for the plots
pasR=(Rmax-Rmin)/200;
pasph=(Pmax-Pmin)/100;
[pht,rt] = meshgrid(Pmin:pasph:Pmax,Rmin:pasR:Rmax);
[X,Y] = pol2cart(pht,rt);

E=zeros(size(rt));
B=zeros(size(rt));
 for j=1:size(pht,2)
     [Ei,Bi]=modefield(ell,m,rt(:,1),theta,pht(1,j),tetm,lambda,R,N);
     E(:,j)=Ei;
     B(:,j)=Bi;
 end
E=E./max(max(E));
B=B./max(max(B));
%
% Plot the electric field
%
figure
colormap(jet)
[VOID,h]=contourf(X,Y,E);
h.LineStyle='none';
colorbar
axis equal
title(['|E|  for ell=',num2str(ell),', m=',...
        num2str(m),', polar angle=',num2str(theta)],'FontSize',14);
%
% Plot the magnetic field
%
figure
colormap(jet)
[VOID,h]=contourf(X,Y,B);
h.LineStyle='none';
colorbar
axis equal
title(['|B| for ell=',num2str(ell),', m=',...
       num2str(m),', polar angle=',num2str(theta)],'FontSize',14);        
end