%QFACT COMPUTES THE QUALITY FACTOR
%  QFACT computes, for a given mode index and a given approximate value
%   of the resonance wavelength the quality factor of the mode.
%  This requires the computation of the exact complex value of the resonance
%   wavelength by solving the exact modal equation

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

clear 
close all
expert_mode=0; % set to 1 for using the program in expert mode
%
% Data reading 
%
R=input('Micro-sphere radius [micro-m] = ');
N=input('Optical index of the micro-sphere = ');
TEM=input('TE or TM mode ? (TE/TM) : ','s');
if strcmp(TEM,'te')
    TEM='TE';
end
if strcmp(TEM,'TE')
    P=N;
else
    P=1/N;
end
ell=input('Mode index ell = ');
rlambda=input('Approximated real value of the resonance wavelength [nm] = ');
rlambda=1E-3*rlambda + 1i*1E-6;  % units conversion in micron-m and add of a small imaginary part 

if expert_mode==1
  tolfun=input('Termination tolerance on the function value; TolFun = ');
  tolx=input('Termination tolerance on the solution value; TolX = ');
  options=optimset('TolFun',tolfun,'TolX',tolx);
  else
  options=optimset('TolFun',1E-14,'TolX',1E-14);
end
disp('----------------------------------------------------------------------')
disp('Non-linear solver fsolve informations')
disp(' ')
[lambda, fvec, info, output, fjac] =fsolve(@(x)cmodeqwv(x,ell,P,R,N,TEM),rlambda,options);
disp('----------------------------------------------------------------------')
Q=abs(real(lambda)/imag(lambda));
disp(['Complex resonance wavelength for the mode in [nm] = ',num2str(lambda*1E3,16)]);
formatSpec = '%s  %6.3e';
tmp=sprintf(formatSpec,'Quality factor for the mode = ',Q);
disp(tmp)