function h=sbesselh(nu,K,Z)
%SBESSELH Spherical Bessel function of the third kind (Hankel function).
%   H = BESSELH(NU,K,Z), for K = 1 or 2, computes the Hankel function
%   H1_nu(Z) or H2_nu(Z) for each element of the complex array Z.
%
%   If NU and Z are arrays of the same size, the result is also that size.
%   If either input is a scalar, it is expanded to the other input's size.

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

h=besselh(nu+0.5,K,Z);
h=sqrt(pi./(2*Z)).*h;
end
