function y=sbessely(nu,Z)
%SBESSELY Spherical Bessel function of the second kind.
%   Y = BESSELY(NU,Z) is the spherical Bessel function of the second kind,
%   y_nu(Z).
%   The order NU need not be an integer, but must be real.
%   The argument Z can be complex.  The result is real where Z is positive.
%
%   If NU and Z are arrays of the same size, the result is also that size.
%   If either input is a scalar, it is expanded to the other input's size.
%   If one input is a row vector and the other is a column vector, the
%   result is a two-dimensional table of function values.

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)


y=bessely(nu+0.5,Z);
y=sqrt(pi./(2*Z)).*y;
end
