function y = slegend(l,m,x)
%SLEGEND Associated Legendre function with Schmidt semi-normalization.
%   P = SLEGEND(L,M,X) computes the associated Legendre function 
%   of degree N and order M with the Schmidt semi-normalization 
%   evaluated for each element of X.
%   N must be a scalar integer and X must contain real values
%   between -1 <= X <= 1.  

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)


% Case when the order exceeds the degree
if abs(m)>l
    y=0; 
    return;
end;
% Compute the associated Legendre functions of degree N and order
% M = 0, 1, ..., N, evaluated for each element of X.
Y=legendre(l,x,'sch');
% Extract the associated Legendre function of degree N and order M
y=Y(m+1,:);
% case of a negative order
if m < 0
    y=(-1)^abs(m) *(factorial(l+m)/factorial(l-m))*y;
end
end

