% VOLTREU WHISPERING GALLERY MODES VOLUME COMPUTATION BY TREUSSART's Formula
%  VOLTREU computes the volume of a whispering gallery TE modes
%         in a micro-sphere by Treussart formula for indexes n=1, ell=|m|
%
% Ref. :  F. Treussart, Ph.D. thesis, University Pierre et Marie Curie,
% Paris, France (1997)
%
% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

R=input('Micro-sphere radius [micro-m] = ');
N=input('Optical index of the micro-sphere = ');
lambda=input('Wavelength [nm] = ');
lambda=1E-3*lambda;  % units conversion
ell=input('Mode number ell = ');

nu=ell+0.5;
% first zero of the spherical Bessel function of first kind
a1= nu+1.8557571*nu^(1./3)+1.033150*nu^(-1./3)-0.00397*nu^(-1)...
    -0.0908*nu^(-5./3);
% first zero of the derivative of the spherical Bessel function of first kind
b1=nu+0.8086165*nu^(1/3)-0.236680*nu^(-1/3)...
    -0.20736*nu^(-1)+0.0233*nu^(-5/3);

V=2*pi^(3./2)*(lambda/(2*pi*N))^3* (a1^3/(2*sqrt(ell)))* ...
                (dsbesselj(ell,a1)/sbesselj(ell,b1))^2;
disp(' ');
disp(['TE mode with index ell= m = ',num2str(ell),' n=1']);
disp([' Mode volume (in micron.m^3) = ',num2str(V)]);
