%WVLRES COMPUTES THE WAVELENGTH AT RESONANCE
%   WVLRES computes, for a given mode index, the values of the wavelength
%   for which a resonance occurs

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 10 september 2017
% Program distributed under the GNU Lesser General Public License (LGPL)

clear 
close all
expert_mode=0; % set to 1 for using the programm in expert mode
%
% Data reading 
%
R=input('Micro-sphere radius [micro-m] = ');
N=input('Optical index of the micro-sphere = ');
TEM=input('TE or TM mode ? (TE/TM) : ','s');
if strcmp(TEM,'te')
    TEM='TE';
end
if strcmp(TEM,'TE')
    P=N;
else
    P=1/N;
end
ell=input('Polar mode index ell = ');
%
% Determine the interval of interest for the wavelength 
%
if expert_mode==0
    alpha=P/(N*sqrt(N^2-1));
    lambda1=2*pi*R/(ell+1/2-alpha);
    lambda2=2*pi*R*N/(ell+1/2-alpha*N);
    disp(' ')
    disp(['Wavelength interval of interest found [nm] = [',num2str(lambda1*1E3),...
    ' , ',num2str(lambda2*1E3),']']);
else
    Inofin=input('Interval of interest for the wavelength search [nm]: ');
    disp(' ')
    lambda1=Inofin(1)*1E-3;
    lambda2=Inofin(2)*1E-3;
end
% Plot the modal equation function which is discontinuous
hpas=(lambda2-lambda1)/10000;
x=lambda1:hpas:lambda2;
y=modeqwv(x,ell,P,R,N,TEM);

if expert_mode==1 
    xx=x*1E3;
    plotd(xx,y);
    ylim([-2 2])
    hold on
    plot(1E3*[lambda1 lambda2], [0 0], 'x-k','LineWidth',2);
    if strcmp(TEM,'TE')
        title('Modale function for TE modes')
    else
        title('Modale function for TM modes')
    end
    xlabel('\lambda [nm]')
    grid
end
%
% Looking for all the resonance wavelengths 
%
tol=1;
options = optimset('TolFun',1E-9,'TolX',1E-9);
j=0;
for k=1:length(x)-1
    % the test ensures that we have a sign change but not a discontinuity
    if (y(k+1)*y(k)<0)&&(abs(y(k+1)-y(k))<tol)
        j=j+1;
        Tlambda(j)=fzero(@(x)modeqwv(x,ell,P,R,N,TEM),[x(k),x(k+1)],options);
    end
end
if j==0
    disp('No solution found ... ')
    return
end
Tlambda=fliplr(Tlambda);
disp(' ')
disp('Radial mode number and resonance wavelength [nm]: ')
disp(' ')
formatSpec = '| %3d | %f |';
for j=1:length(Tlambda)
    tmp=sprintf(formatSpec,j,1E3*Tlambda(j));
    disp(tmp);
end
disp(' ');

if expert_mode==1 
    rep=input('Compare results to the Eikonale equation ? [y/n] : ','s');
    if strcmp(rep,'n'), return, end;
    disp(' ')
    disp('Radial mode number and resonance wavelength from the Eikonale equation [nm]: ')
    disp(' ')
    formatSpec = '| %3d | %f |';
        for n=1:length(Tlambda) % loop over Mode index n
            tmp=ell+0.5+ ((ell+0.5)/2)^(1/3)*(1.5*pi*(n-0.25))^(2/3)...
                -P/sqrt(N^2-1);
            lambdae=(N*2*pi*R)/tmp;
            tmp=sprintf(formatSpec,n,1E3*lambdae);
            disp(tmp);
        end
    end
